<?php
/**
 * OxygenOrder Class File
 *
 * @package Oxygen
 * @summary Class to add WooCommerce order hooks
 * @version 1.0.0
 * @since  1.0.0
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Oxygen MyData Class
 */
class OxygenOrder {



	/**
	 * Singleton Instance of OxygenOrder
	 *
	 * @var OxygenOrder
	 **/
	private static $instance = null;

	/**
	 * WooCommerce order ID
	 *
	 * @var int order ID
	 */
	private static $order_id = null;


	/**
	 * Singleton init Function
	 *
	 * @static
	 */
	public static function init() {
		if ( ! self::$instance ) {
			self::$instance = new self();

		}
		return self::$instance;
	}

	/**
	 * Oxygen Constructor
	 */
	private function __construct() {

		$this->init_hooks();
	}

	/**
	 *  Add all order hooks
	 *
	 *  @return void
	 */
	private function init_hooks() {

		add_action( 'add_meta_boxes', array( $this, 'add_meta_box' ) );
		add_action( 'admin_init', array( $this, 'oxygen_actions' ) );
		add_action( 'save_post_shop_order', array( $this, 'save_order' ), 10, 3 );
		add_action( 'woocommerce_new_order', array( $this, 'on_order_create' ), 10, 1 );

		if ( 'yes' === get_option( 'oxygen_self_fields' ) ) {

			// Add VAT fields in billing address display.
			add_filter( 'woocommerce_checkout_fields', array( $this, 'override_checkout_fields' ) );
			add_filter( 'woocommerce_address_to_edit', array( $this, 'oxygen_address_to_edit' ), 10, 2 );
			add_filter( 'woocommerce_order_formatted_billing_address', array( $this, 'oxygen_order_formatted_billing_address' ), 10, 2 );
			add_filter( 'woocommerce_my_account_my_address_formatted_address', array( $this, 'oxygen_my_account_my_address_formatted_address' ), 10, 3 );
			add_filter( 'woocommerce_formatted_address_replacements', array( $this, 'oxygen_formatted_address_replacements' ), 10, 2 );
			add_filter( 'woocommerce_admin_billing_fields', array( $this, 'oxygen_admin_billing_fields' ), 10, 1 );
			add_filter( 'woocommerce_ajax_get_customer_details', array( $this, 'oxygen_found_customer_details' ), 10, 3 );
			add_filter( 'woocommerce_customer_meta_fields', array( $this, 'oxygen_customer_meta_fields' ), 10, 1 );

			add_filter( 'woocommerce_my_account_my_orders_actions', array( $this, 'my_account_my_orders_actions' ), 9999, 2 );

		}

		$oxygen_order_status = str_replace( 'wc-', '', OxygenWooSettings::get_option( 'oxygen_order_status' ) );

		add_action( 'woocommerce_order_status_' . $oxygen_order_status, array( $this, 'create_invoice' ), 10, 2 );

		// add extra order list column(s).
		add_filter( 'manage_edit-shop_order_columns', array( $this, 'shop_order_column' ), 20 );
		add_action( 'manage_shop_order_posts_custom_column', array( $this, 'orders_list_column_content' ), 20, 2 );
	}

	/**
	 *  Create the metabox for Oxygen order data.
	 *
	 *  @return void
	 */
	public function add_meta_box() {
		add_meta_box( 'oxygen_order_extra', __( 'Oxygen', 'oxygen' ), array( $this, 'order_metabox_content' ), 'shop_order', 'side', 'core' );
	}

	/**
	 *  Create the content of the Oxygen order metabox.
	 *
	 *  @return void
	 */
	public function order_metabox_content() {

		global $post;

		self::$order_id = $post->ID;

		$check = OxygenApi::check_connection();

		if ( ! $check ) {
			?>
			<a href="<?php echo esc_url( get_admin_url() . 'admin.php?page=wc-settings&tab=oxygen' ); ?>">
			<?php esc_html_e( 'Oxygen setup', 'oxygen' ); ?>
			</a>
			<?php
			return;
		}

		$nonce = wp_create_nonce( 'oxygen-' . $post->ID . '-nonce' );

		$_oxygen_payment_note_type = sanitize_text_field( get_post_meta( $post->ID, '_oxygen_payment_note_type', true ) );

		$document_type_names = OxygenWooSettings::document_type_names();
		unset( $document_type_names['notice'] );

		$invoice_data = get_post_meta( self::$order_id, '_oxygen_invoice', true );
		$notice_data  = get_post_meta( self::$order_id, '_oxygen_notice', true );
		$pdf          = get_post_meta( self::$order_id, '_oxygen_invoice_pdf', true );

		if ( isset( $invoice_data['iview_url'] ) && ! empty( $invoice_data['iview_url'] ) ) {
			?>
			<div>
				<p><a href="<?php echo esc_url( $invoice_data['iview_url'] ); ?>" target="_blank" class="button wide-fat"><span class="dashicons dashicons-search"></span> <?php esc_html_e( 'View Invoice', 'oxygen' ); ?></a></p>
				<p><a href="<?php echo esc_url( $pdf ); ?>" target="_blank" class="button wide-fat"><span class="dashicons dashicons-pdf"></span> <?php esc_html_e( 'PDF Download', 'oxygen' ); ?></a></p>
				<p><?php esc_html_e( 'Oxygen invoice:', 'oxygen' ); ?>
					<strong><a href="<?php echo esc_url( $invoice_data['iview_url'] ); ?>" target="_blank"><?php echo esc_html( $invoice_data['sequence'] ) . esc_html( $invoice_data['number'] ); ?></a></strong>
				</p>				
			</div>
			<?php
		} else {

			wp_nonce_field( 'oxygen-' . $post->ID . '-nonce', 'oxygen_nonce' );
			?>

			<div>
				<label for="_oxygen_payment_note_type"><?php esc_html_e( 'Payment Note Type', 'oxygen' ); ?></label>
				<p>
					<select name="_oxygen_payment_note_type" id="_oxygen_payment_note_type" class="wide wide-fat">
						<option value=""></option>
						<?php foreach ( $document_type_names as $key => $type ) { ?>
						<option value="<?php echo esc_attr( $key ); ?>" <?php selected( $_oxygen_payment_note_type, $key ); ?>><?php echo esc_html( $type ); ?></option>
						<?php } ?>

					</select><br />
				</p>
			</div>

			<div>
				<p>
				<a href="<?php echo esc_url( get_admin_url() . 'post.php?post=' . intval( $post->ID ) . '&action=edit&oxygen=create_invoice&_wpnonce=' . esc_attr( $nonce ) ); ?>" class="button create_invoice button-primary disabled"><?php esc_html_e( 'Create Invoice', 'oxygen' ); ?></a>
				</p>

				<?php if ( ! empty( $notice_data ) && isset( $notice_data['iview_url'] ) && ! empty( $notice_data['iview_url'] ) ) { ?>

					<p><a href="<?php echo esc_url( $notice_data['iview_url'] ); ?>" target="_blank" class="button wide-fat"><span class="dashicons dashicons-media-document" style="transform: translateY(4px)"></span> <?php esc_html_e( 'View Notice', 'oxygen' ); ?></a></p>

				<?php } ?>
					<p>
					<a href="<?php echo esc_url( get_admin_url() . 'post.php?post=' . intval( $post->ID ) . '&action=edit&oxygen=create_notice&_wpnonce=' . esc_attr( $nonce ) ); ?>" class="button action create_notice"><?php esc_html_e( 'Create Notice', 'oxygen' ); ?></a>
					</p>
			</div>
			<script>
			jQuery( document ).ready( function($) {		

				if ( $('#_oxygen_payment_note_type').length > 0 ) {

					var $type = $('#_oxygen_payment_note_type').val();

					if ( $type == '' ) {

						$( '.create_invoice' ).addClass( 'disabled' );

					} else {

						$( '.create_invoice' ).removeClass( 'disabled' );
					}

					$('#_oxygen_payment_note_type').on( 'change', function() {

						var $dropthis = $( this );
						$type = $dropthis.val();

						if ( $dropthis.val() == '' ) {

							$( '.create_invoice' ).addClass( 'disabled' );

							return;

						} else {

							$( '.create_invoice' ).removeClass( 'disabled' );
						}

					});

					$( '.create_invoice,.create_notice' ).on( 'click', function( e ) {

						e.preventDefault();

						window.location.href = $( this ).attr( 'href' )+'&_oxygen_payment_note_type='+$type;

						return false;

					});

				}

			});
			</script>
			<?php
		}

		if ( ! isset( $_GET['oxygen'] ) || ! isset( $_GET['_wpnonce'] ) ) {

			WC_Admin_Notices::remove_notice( 'oxygen_payment_note_missing' );
			WC_Admin_Notices::remove_notice( 'oxygen_invalid_action' );
			WC_Admin_Notices::remove_notice( 'oxygen_payment_method_missing' );
			WC_Admin_Notices::remove_notice( 'oxygen_invoice_info_missing' );
			WC_Admin_Notices::remove_notice( 'oxygen_contact_error' );
			WC_Admin_Notices::remove_notice( 'oxygen_invoice_error' );
			WC_Admin_Notices::remove_notice( 'oxygen_invoice_success' );
			WC_Admin_Notices::remove_notice( 'oxygen_notice_success' );
			WC_Admin_Notices::remove_notice( 'oxygen_no_api' );

			return;
		}
	}

	/**
	 *  Trigger Oxygen actions for invoice and notices creation.
	 *
	 *  @return void
	 */
	public function oxygen_actions() {

		if ( ! is_admin() ) {
			return;
		}

		if ( ! isset( $_GET['oxygen'] ) || ! isset( $_GET['_wpnonce'] ) ) {

			return;
		}

		$oxygen_api_key = get_option( 'oxygen_api_key' );

		if ( empty( $oxygen_api_key ) ) {
			/* translators: %s: URL to Oxygen platform */
			WC_Admin_Notices::add_custom_notice( 'oxygen_no_api', sprintf( __( '<p>The Oxygen API key is missing. <a href="%s">Click here to add one</a>.</p>', 'oxygen' ), get_admin_url() . 'admin.php?page=wc-settings&tab=oxygen' ) );
			WC_Admin_Notices::output_custom_notices();

			WC_Admin_Notices::remove_notice( 'oxygen_no_api' );

			return;
		}

		if ( isset( $_REQUEST['_wpnonce'] ) ) {
			$nonce = sanitize_key( $_REQUEST['_wpnonce'] );
		} else {
			return;
		}

		$post_id = 0;

		if ( isset( $_REQUEST['post'] ) ) {
			$post_id = intval( $_REQUEST['post'] );
		}

		$verify = wp_verify_nonce( $nonce, 'oxygen-' . $post_id . '-nonce' );

		if ( ! $verify ) {

			WC_Admin_Notices::add_custom_notice( 'oxygen', '<p>Could not verify request</p>' );
			WC_Admin_Notices::output_custom_notices();

			WC_Admin_Notices::remove_notice( 'oxygen' );

			return;
		}

		$order = wc_get_order( $post_id );
		if ( ! $order ) {
			return;
		}

		$oxygen_action = sanitize_text_field( wp_unslash( $_GET['oxygen'] ) );

		$_GET['notetype'] = false;

		if ( ( isset( $_GET['_oxygen_payment_note_type'] ) && ! empty( $_GET['_oxygen_payment_note_type'] ) ) || ( empty( $_GET['_oxygen_payment_note_type'] ) && 'create_notice' === $oxygen_action ) ) {

			if ( 'create_invoice' === $oxygen_action ) {

				$_GET['notetype'] = 'invoice';

				self::create_invoice( $order->get_id(), $order );

			} elseif ( 'create_notice' === $oxygen_action ) {

				$_GET['notetype'] = 'notice';

				self::create_invoice( $order->get_id(), $order );

			} else {

				WC_Admin_Notices::add_custom_notice( 'oxygen_invalid_action', '<p>' . __( 'Invalid Oxygen action', 'oxygen' ) . '</p>' );
			}
		} else {

				WC_Admin_Notices::add_custom_notice( 'oxygen_payment_note_missing', '<p>' . __( 'Payment Note Type has not been defined', 'oxygen' ) . '</p>' );

		}

	}

	/**
	 *  Create order invoice on Oxygen API
	 *
	 *  @param array  $order_id the WC order ID.
	 *  @param object $order WC_Order.
	 *  @return array|false
	 */
	public static function create_invoice( $order_id, $order ) {

		if ( isset( $_REQUEST['_wpnonce'] ) ) {
			$nonce = sanitize_key( $_REQUEST['_wpnonce'] );
		} else {
			return;
		}

		$post_id = 0;

		if ( isset( $_REQUEST['post'] ) ) {
			$post_id = intval( $_REQUEST['post'] );
		}

		$verify = wp_verify_nonce( $nonce, 'oxygen-' . $post_id . '-nonce' );

		if ( ! $verify ) {

			WC_Admin_Notices::add_custom_notice( 'oxygen', '<p>Could not verify request</p>' );
			WC_Admin_Notices::output_custom_notices();

			WC_Admin_Notices::remove_notice( 'oxygen' );

			return;
		}

		$doc_key = false;

		if ( isset( $_GET['_oxygen_payment_note_type'] ) ) {
			$doc_key = sanitize_text_field( wp_unslash( $_GET['_oxygen_payment_note_type'] ) );
		}

		$oxygen_default_receipt_doctype = get_option( 'oxygen_default_receipt_doctype' );
		$oxygen_default_invoice_doctype = get_option( 'oxygen_default_invoice_doctype' );

		if ( ! isset( $_GET['notetype'] ) ) {

			WC_Admin_Notices::add_custom_notice( 'oxygen_payment_note_missing', '<p>' . __( 'Invalid Payment Note Type', 'oxygen' ) . '</p>' );

			return false;

		}

		$notetype = sanitize_text_field( wp_unslash( $_GET['notetype'] ) );

		if ( 'notice' === $_GET['notetype'] ) {
			$doc_key = 'notice';
		}

		if ( isset( $_GET['oxygen'] ) && 'notice' !== $notetype && empty( $doc_key ) ) {

			WC_Admin_Notices::add_custom_notice( 'oxygen_payment_note_missing', '<p>' . __( 'Payment Note Type has not been defined', 'oxygen' ) . '</p>' );

			return false;

		}

		$get_billing_vat_info = self::get_billing_vat_info( $order_id );

		if ( ! isset( $_GET['oxygen'] ) ) {

			// set the default document type.

			if ( false !== $get_billing_vat_info && ! empty( $order->get_billing_company() ) && ! empty( $oxygen_default_invoice_doctype ) ) {

				update_post_meta( $order_id, '_oxygen_payment_note_type', $oxygen_default_invoice_doctype );
				$doc_key = $oxygen_default_invoice_doctype;

			} else {

				if ( ! empty( $oxygen_default_receipt_doctype ) ) {

					update_post_meta( $order_id, '_oxygen_payment_note_type', $oxygen_default_receipt_doctype );
					$doc_key = $oxygen_default_receipt_doctype;

				}
			}
		} else {

			update_post_meta( $order_id, '_oxygen_payment_note_type', $doc_key );
		}

		$class_cat_subfix = '';
		if ( 'alp' === $doc_key || 'apy' === $doc_key ) {
			$class_cat_subfix = '_receipt';
		}

		$document_types  = OxygenWooSettings::document_types();
		$mydata_types    = OxygenWooSettings::mydata_document_types();
		$payment_methods = OxygenWooSettings::get_option( 'oxygen_payment_methods' );
		$oxygen_taxes    = OxygenWooSettings::oxygen_tax_options();

		if ( ! isset( $payment_methods[ $order->get_payment_method() ] ) ) {

			WC_Admin_Notices::add_custom_notice( 'oxygen_payment_method_missing', '<p>' . __( 'Payment method not found', 'oxygen' ) . '</p>' );

			return false;
		}

		$oxygen_customer_id = false;
		$customer           = get_user_by( 'email', $order->get_billing_email() );
		if ( ! empty( $customer ) ) {
			$oxygen_customer_id = get_user_meta( $customer->ID, 'oxygen_id', true );

			// make sure that the customer exists on the API.
			if ( ! empty( $oxygen_customer_id ) ) {

				$oxygen_contact = OxygenApi::get_contact( $oxygen_customer_id );

				if ( empty( $oxygen_contact ) || ( is_array( $oxygen_contact ) && ! isset( $oxygen_contact['id'] ) ) ) {
					$oxygen_customer_id = false;
				}
			}
		}

		// if there is not a custom OR there is a customer in the WP DB AND the customer ID is missing, search user by VAT# .
		if ( empty( $customer ) || ( ! empty( $customer ) && ! $oxygen_customer_id ) ) {

			if ( isset( $get_billing_vat_info['billing_vat'] ) ) {

				$oxygen_contact = OxygenApi::get_contact_by_vat( $get_billing_vat_info['billing_vat'] );

				if ( isset( $oxygen_contact['data'] ) && isset( $oxygen_contact['data'][0]['id'] ) ) {

					$oxygen_customer_id = $oxygen_contact['data'][0]['id'];
				}
			}
		}

		if ( 'notice' !== $notetype ) {
			if ( ( 'tpda' === $doc_key || 'tpy' === $doc_key ) && false === $get_billing_vat_info ) {

				WC_Admin_Notices::add_custom_notice( 'oxygen_invoice_info_missing', '<p>' . __( 'Invoice details are missing or incomplete', 'oxygen' ) . '</p>' );

				return false;

			}
		}

		$customer_type = 1;

		// get contact arguments.
		if ( ! $oxygen_customer_id ) {

			$billing_vat        = false;
			$billing_job        = false;
			$billing_tax_office = false;
			$customer_type      = 1;

			if ( $get_billing_vat_info ) {

				$billing_vat        = $get_billing_vat_info['billing_vat'];
				$billing_job        = $get_billing_vat_info['billing_job'];
				$billing_tax_office = $get_billing_vat_info['billing_tax_office'];
				$billing_invoice    = $get_billing_vat_info['billing_invoice'];

				// set customer type to 2 ONLY if all values are set.
				if ( false !== $billing_vat && ! empty( $order->get_billing_company() ) ) {
					$customer_type = 2;
				}
			}

			$contact_args = array_filter(
				array(
					'code'         => '',
					'type'         => $customer_type,
					'is_client'    => true,
					'name'         => $order->get_billing_first_name(),
					'surname'      => $order->get_billing_last_name(),
					'company_name' => $order->get_billing_company(),
					'profession'   => $billing_job,
					'vat_number'   => $billing_vat,
					'tax_office'   => $billing_tax_office,
					'telephone'    => $order->get_billing_phone(),
					'mobile'       => $order->get_billing_phone(),
					'email'        => $order->get_billing_email(),
					'street'       => str_replace( '  ', ' ', preg_replace( '/\d+/', '', $order->get_billing_address_1() ) ) . ( ! empty( $order->get_billing_address_2() ) ? ', ' . $order->get_billing_address_2() : '' ),
					'number'       => intval( ( preg_replace( '/[^0-9]/', '', $order->get_billing_address_1() ) ? preg_replace( '/[^0-9]/', '', $order->get_billing_address_1() ) : 0 ) ),
					'city'         => $order->get_billing_city(),
					'zip_code'     => $order->get_billing_postcode(),
					'country'      => $order->get_billing_country(),
				)
			);

			if ( empty( $billing_vat ) ) {
				unset( $contact_args['vat_number'] );
			}

			$log = array( '----------------- NEW CONTACT -----------------', $contact_args );
			OxygenWooSettings::debug( $log );

			$contact_args['is_supplier'] = false;

			$contact = json_decode( OxygenApi::add_contact( $contact_args ), true );

			if ( is_array( $contact ) && isset( $contact['id'] ) ) {

				if ( $customer ) {
					update_user_meta( $customer->ID, 'oxygen_id', $contact['id'] );
				}
				$oxygen_customer_id = $contact['id'];

			} else {

				$errors = array();

				foreach ( $contact['errors'] as $error ) {

					$errors[] = implode( ',', $error );

				}

				WC_Admin_Notices::add_custom_notice( 'oxygen_contact_error', '<p>' . __( 'Could not create contact', 'oxygen' ) . ' | ' . implode( ',', $errors ) . '</p>' );

				return false;
			}
		}

		if ( 'notice' === $notetype ) {

			$args = array_filter(
				array(
					'numbering_sequence_id' => OxygenWooSettings::get_option( 'oxygen_num_sequence' . $doc_key ),
					'issue_date'            => wp_date( 'Y-m-d' ),
					'expire_date'           => wp_date( 'Y-m-d', strtotime( '+1 month' ) ),
					'language'              => 'GR',
					'contact_id'            => $oxygen_customer_id,
				)
			);

		} else {

			$args = array_filter(
				array(
					'numbering_sequence_id' => OxygenWooSettings::get_option( 'oxygen_num_sequence' . $doc_key ),
					'issue_date'            => wp_date( 'Y-m-d' ),
					'document_type'         => $document_types[ $doc_key ], // p or rp if physical product exists.
					'language'              => 'GR',
					'mydata_document_type'  => $mydata_types[ $doc_key ],
					'payment_method_id'     => $payment_methods[ $order->get_payment_method() ],
					'contact_id'            => $oxygen_customer_id,
				)
			);
		}

		$oxygen_taxes = get_option( 'oxygen_taxes' );

		$items = $order->get_items();

		foreach ( $items as $item_id => $item ) {

			$taxes = $item->get_taxes();

			$item_rate_id = false;

			foreach ( $taxes['total'] as $rate_id => $amount ) {

				if ( ! empty( $amount ) ) {

					$item_rate_id = $rate_id;
					break;
				}
			}

			if ( 'notice' === $notetype ) {
				$get_product_mydata_info = self::get_product_mydata_receipt_info( $item->get_product_id() );
			} else {
				$get_product_mydata_info = self::get_product_mydata_info( $item->get_product_id() );
			}

			$args['items'][] = array(
				'description'                    => $item->get_name(),
				'quantity'                       => $item->get_quantity(),
				'unit_net_value'                 => round( ( $item->get_total() / $item->get_quantity() ), 2 ),
				'tax_id'                         => $oxygen_taxes[ $rate_id ],
				'vat_amount'                     => $item->get_total_tax(),
				'net_amount'                     => $item->get_total(),
				'mydata_classification_category' => ( is_array( $get_product_mydata_info[ 'mydata_category' . $class_cat_subfix ] ) ? $get_product_mydata_info[ 'mydata_category' . $class_cat_subfix ][0] : $get_product_mydata_info[ 'mydata_category' . $class_cat_subfix ] ),
				'mydata_classification_type'     => ( is_array( $get_product_mydata_info[ 'mydata_classification_type' . $class_cat_subfix ] ) ? $get_product_mydata_info[ 'mydata_classification_type' . $class_cat_subfix ][0] : $get_product_mydata_info[ 'mydata_classification_type' . $class_cat_subfix ] ),
			);

		}

		$items = $order->get_items( array( 'shipping' ) );

		foreach ( $items as $item_id => $item ) {

			if ( 0 === floatval( $item->get_total() ) ) {
				continue;
			}

			$taxes = $item->get_taxes();

			$item_rate_id = false;

			foreach ( $taxes['total'] as $rate_id => $amount ) {

				if ( ! empty( $amount ) ) {

					$item_rate_id = $rate_id;
					break;
				}
			}

			$get_item_mydata_info = $item->get_data();

			$args['items'][] = array(
				'description'                    => __( 'Shipping: ', 'oxygen' ) . $item->get_name(),
				'quantity'                       => $item->get_quantity(),
				'unit_net_value'                 => round( ( $item->get_total() / $item->get_quantity() ), 2 ),
				'tax_id'                         => $oxygen_taxes[ $rate_id ],
				'vat_amount'                     => $item->get_total_tax(),
				'net_amount'                     => $item->get_total(),
				'mydata_classification_category' => 'category1_5',
				'mydata_classification_type'     => 'E3_562',
			);

		}

		$items = $order->get_items( array( 'fee' ) );

		foreach ( $items as $item_id => $item ) {

			$taxes = $item->get_taxes();

			$item_rate_id = false;

			foreach ( $taxes['total'] as $rate_id => $amount ) {

				if ( ! empty( $amount ) ) {

					$item_rate_id = $rate_id;
					break;
				}
			}

			$get_item_mydata_info = $item->get_data();

			if ( 'notice' === $notetype ) {
				$get_product_mydata_info = array(
					'mydata_category'            => get_option( 'mydata_category_receipt' ),
					'mydata_classification_type' => get_option( 'mydata_classification_type_receipt' ),
				);
			} else {
				$get_product_mydata_info = array(
					'mydata_category'                    => get_option( 'mydata_category' ),
					'mydata_classification_type'         => get_option( 'mydata_classification_type' ),
					'mydata_category_receipt'            => get_option( 'mydata_category_receipt' ),
					'mydata_classification_type_receipt' => get_option( 'mydata_classification_type_receipt' ),
				);
			}

			if ( $item->get_total() < 0 ) {
				$args['items'][] = array(
					'description'                    => $item->get_name(),
					'quantity'                       => $item->get_quantity(),
					'unit_net_value'                 => round( ( $item->get_total() / $item->get_quantity() ), 2 ),
					'tax_id'                         => $oxygen_taxes[ $rate_id ],
					'vat_amount'                     => $item->get_total_tax(),
					'net_amount'                     => $item->get_total(),
					'mydata_classification_category' => ( is_array( $get_product_mydata_info[ 'mydata_category' . $class_cat_subfix ] ) ? $get_product_mydata_info[ 'mydata_category' . $class_cat_subfix ][0] : $get_product_mydata_info[ 'mydata_category' . $class_cat_subfix ] ),
					'mydata_classification_type'     => ( is_array( $get_product_mydata_info[ 'mydata_classification_type' . $class_cat_subfix ] ) ? $get_product_mydata_info[ 'mydata_classification_type' . $class_cat_subfix ][0] : $get_product_mydata_info[ 'mydata_classification_type' . $class_cat_subfix ] ),
				);
			} else {

				$args['items'][] = array(
					'description'                    => $item->get_name(),
					'quantity'                       => $item->get_quantity(),
					'unit_net_value'                 => round( ( $item->get_total() / $item->get_quantity() ), 2 ),
					'tax_id'                         => $oxygen_taxes[ $rate_id ],
					'vat_amount'                     => $item->get_total_tax(),
					'net_amount'                     => $item->get_total(),
					'mydata_classification_category' => 'category1_5',
					'mydata_classification_type'     => 'E3_562',
				);
			}
		}

		$log = array( '----------------- ' . $notetype . ' args log -----------------', $args, $order_id );
		OxygenWooSettings::debug( $log );

		if ( 'notice' === $notetype ) {

			$result = OxygenApi::add_notice( $args );

		} else {

			$result = OxygenApi::add_invoice( $args );

		}

		if ( is_array( $result ) && isset( $result['body'] ) ) {
			$add_invoice = json_decode( $result['body'], true );
		} else {
			$add_invoice = json_decode( $result, true );
		}

		if ( is_array( $add_invoice ) && isset( $add_invoice['id'] ) ) {

			if ( 'notice' === $notetype ) {

				update_post_meta( $order_id, '_oxygen_notice', $add_invoice );
				WC_Admin_Notices::add_custom_notice( 'oxygen_notice_success', '<p>' . __( 'Notice Created', 'oxygen' ) . '</p>' );

			} else {

				update_post_meta( $order_id, '_oxygen_invoice', $add_invoice );

				$upload_dir = wp_upload_dir();
				$oxyge_path = $upload_dir['basedir'] . '/oxygen';
				if ( ! is_dir( $oxyge_path ) ) {
					wp_mkdir_p( $oxyge_path );
				}

				$pdf_path = $upload_dir['basedir'] . '/oxygen/' . $add_invoice['id'] . '.pdf';
				$pdf_url  = $upload_dir['baseurl'] . '/oxygen/' . $add_invoice['id'] . '.pdf';

				$oxygen_pdf = OxygenApi::get_invoice_pdf( $add_invoice['id'] );

				$file_put = file_put_contents( $pdf_path, $oxygen_pdf['body'] );

				if ( $file_put ) {

					update_post_meta( $order_id, '_oxygen_invoice_pdf', $pdf_url );
					WC_Admin_Notices::add_custom_notice( 'oxygen_invoice_success', '<p>' . __( 'Invoice Created', 'oxygen' ) . '</p>' );

				} else {

					WC_Admin_Notices::add_custom_notice( 'oxygen_invoice_error', '<p>' . __( 'Could not save PDF invoice file in ', 'oxygen' ) . $pdf_path . '</p>' );

				}
			}

			if ( ! isset( $_GET['oxygen'] ) ) {
				return;
			}
		} else {

			$errors = array();

			if ( isset( $add_invoice['errors'] ) ) {

				foreach ( $add_invoice['errors'] as $error ) {

					$errors[] = implode( ',', $error );

				}
			} else {

				$errors = $add_invoice;

			}

			if ( 'notice' === $notetype ) {

				WC_Admin_Notices::add_custom_notice( 'oxygen_invoice_error', '<p>' . __( 'Could not create notice', 'oxygen' ) . ' | ' . implode( ',', $errors ) . '</p>' );
			} else {

				WC_Admin_Notices::add_custom_notice( 'oxygen_invoice_error', '<p>' . __( 'Could not create invoice', 'oxygen' ) . ' | ' . implode( ',', $errors ) . '</p>' );
			}

			$log = array( '----------------- ' . $notetype . ' error -----------------', $args, $add_invoice );
			OxygenWooSettings::debug( $log );
		}

		wp_safe_redirect( get_admin_url() . 'post.php?post=' . $order_id . '&action=edit' );
		die;
	}

	/**
	 *  Get the customer billing VAT data by order ID.
	 *
	 *  @param array $order_id the WC order ID.
	 *  @return array|false
	 */
	public static function get_billing_vat_info( $order_id ) {

		$billing_vat        = false;
		$billing_job        = false;
		$billing_tax_office = false;
		$billing_invoice    = false;

		if ( 'yes' === get_option( 'oxygen_self_fields' ) ) {

			$billing_vat        = get_post_meta( $order_id, '_billing_vat', true );
			$billing_job        = get_post_meta( $order_id, '_billing_job', true );
			$billing_tax_office = get_post_meta( $order_id, '_billing_tax_office', true );
			$billing_invoice    = get_post_meta( $order_id, '_billing_invoice', true );

		} else {

			$oxygen_vat_metakey           = get_option( 'oxygen_vat_metakey' );
			$oxygen_working_field_metakey = get_option( 'oxygen_working_field_metakey' );
			$oxygen_tax_office            = get_option( 'oxygen_tax_office' );
			$oxygen_issue_invoice_metakey = get_option( 'oxygen_issue_invoice_metakey' );

			$billing_vat        = get_post_meta( $order_id, $oxygen_vat_metakey, true );
			$billing_job        = get_post_meta( $order_id, $oxygen_working_field_metakey, true );
			$billing_tax_office = get_post_meta( $order_id, $oxygen_tax_office, true );
			$billing_invoice    = get_post_meta( $order_id, $oxygen_issue_invoice_metakey, true );
		}

		if ( empty( $billing_vat ) ) {
			$billing_vat = get_post_meta( $order_id, '_billing_vat', true );
		}
		if ( empty( $billing_job ) ) {
			$billing_job = get_post_meta( $order_id, '_billing_job', true );
		}
		if ( empty( $billing_tax_office ) ) {
			$billing_tax_office = get_post_meta( $order_id, '_billing_tax_office', true );
		}
		if ( empty( $billing_invoice ) ) {
			$billing_invoice = get_post_meta( $order_id, 'billing_invoice', true );
		}

		if ( ! empty( $billing_vat ) && ! empty( $billing_job ) && ! empty( $billing_invoice ) ) {

			$info = array(
				'billing_vat'        => $billing_vat,
				'billing_job'        => $billing_job,
				'billing_tax_office' => $billing_tax_office,
				'billing_invoice'    => $billing_invoice,
			);
			return $info;

		}

		return false;
	}

	/**
	 *  Create customer billing address extra fields.
	 *
	 *  @param array $fields customer billing address data.
	 *  @return array
	 */
	public function override_checkout_fields( $fields ) {

		$fields['billing']['billing_vat']        = array(
			'type'        => 'text',
			'label'       => __( 'VAT #', 'oxygen' ),
			'placeholder' => __( 'ex. EL1234567890', 'oxygen' ),
			'priority'    => 150,
		);
		$fields['billing']['billing_job']        = array(
			'type'        => 'text',
			'label'       => __( 'Job Description Field', 'oxygen' ),
			'placeholder' => __( 'ex. Accountant', 'oxygen' ),
			'priority'    => 151,
		);
		$fields['billing']['billing_tax_office'] = array(
			'type'        => 'text',
			'label'       => __( 'Tax Office', 'oxygen' ),
			'placeholder' => __( 'ex. D', 'oxygen' ),
			'priority'    => 152,
		);
		$fields['billing']['billing_invoice']    = array(
			'type'     => 'checkbox',
			'label'    => __( 'I need an invoice', 'oxygen' ),
			'id'       => 'billing_invoice',
			'priority' => 153,
		);
		return $fields;

	}

	/**
	 *  Create customer billing address extra fields.
	 *
	 *  @param array  $address customer billing address fields data.
	 *  @param string $load_address address type.
	 *  @return array
	 */
	public function oxygen_address_to_edit( $address, $load_address ) {
		global $wp_query;

		if ( isset( $wp_query->query_vars['edit-address'] ) && 'billing' !== $wp_query->query_vars['edit-address'] ) {
			return $address;
		}

		if ( ! isset( $address['billing_vat'] ) ) {
			$address['billing_vat'] = array(
				'label'       => __( 'VAT #', 'oxygen' ),
				'placeholder' => _x( 'VAT #', 'placeholder', 'oxygen' ),
				'required'    => false,
				'class'       => array( 'form-row-first' ),
				'value'       => sanitize_text_field( get_user_meta( get_current_user_id(), 'billing_vat', true ) ),
			);
		}

		if ( ! isset( $address['billing_job'] ) ) {
			$address['billing_job'] = array(
				'label'       => __( 'Job Description Field', 'oxygen' ),
				'placeholder' => _x( 'Job Description Field', 'placeholder', 'oxygen' ),
				'required'    => false,
				'class'       => array( 'form-row-last' ),
				'value'       => sanitize_text_field( get_user_meta( get_current_user_id(), 'billing_job', true ) ),
			);
		}
		if ( ! isset( $address['billing_tax_office'] ) ) {
			$address['billing_tax_office'] = array(
				'label'       => __( 'Tax Office', 'oxygen' ),
				'placeholder' => _x( 'Tax Office', 'placeholder', 'oxygen' ),
				'required'    => false,
				'class'       => array( 'form-row-first' ),
				'value'       => sanitize_text_field( get_user_meta( get_current_user_id(), 'billing_tax_office', true ) ),
			);
		}

		if ( ! isset( $address['billing_invoice'] ) ) {
			$address['billing_invoice'] = array(
				'label'       => __( 'Issue invoice', 'oxygen' ),
				'placeholder' => _x( 'Issue invoice', 'placeholder', 'oxygen' ),
				'required'    => false,
				'class'       => array( 'form-row-last' ),
				'value'       => sanitize_text_field( get_user_meta( get_current_user_id(), 'billing_invoice', true ) ),
				'type'        => 'checkbox',
			);
		}

		return $address;
	}

	/**
	 *  Create customer billing address extra fields.
	 *
	 *  @param array  $fields customer meta data array.
	 *  @param object $order WC_Order.
	 *  @return array
	 */
	public function oxygen_order_formatted_billing_address( $fields, $order ) {
		$fields['billing_vat']        = sanitize_text_field( get_post_meta( $order->get_id(), '_billing_vat', true ) );
		$fields['billing_job']        = sanitize_text_field( get_post_meta( $order->get_id(), '_billing_job', true ) );
		$fields['billing_tax_office'] = sanitize_text_field( get_post_meta( $order->get_id(), '_billing_tax_office', true ) );
		$fields['billing_invoice']    = sanitize_text_field( get_post_meta( $order->get_id(), '_billing_invoice', true ) );

		return $fields;
	}


	/**
	 *  Adding new customer billing fields to the order.
	 *
	 *  @param array  $fields customer meta data array.
	 *  @param int    $customer_id order user ID.
	 *  @param string $type address type.
	 *  @return array
	 */
	public function oxygen_my_account_my_address_formatted_address( $fields, $customer_id, $type ) {

		if ( 'billing' === $type ) {
			$fields['vat']        = sanitize_text_field( get_user_meta( $customer_id, 'billing_vat', true ) );
			$fields['job']        = sanitize_text_field( get_user_meta( $customer_id, 'billing_job', true ) );
			$fields['tax_office'] = sanitize_text_field( get_user_meta( $customer_id, 'billing_tax_office', true ) );
			$fields['invoice']    = sanitize_text_field( get_user_meta( $customer_id, 'billing_invoice', true ) );
		}

		return $fields;
	}

	/**
	 *  Adding new customer billing fields to the order.
	 *
	 *  @param array $address customer address data.
	 *  @param array $args customer address data.
	 *  @return array
	 */
	public function oxygen_formatted_address_replacements( $address, $args ) {

		$address['{vat}']        = '';
		$address['{job}']        = '';
		$address['{tax_office}'] = '';
		$address['{invoice}']    = '';

		if ( ! empty( $args['vat'] ) ) {
			$address['{vat}'] = __( 'VAT #', 'oxygen' ) . ' ' . strtoupper( $args['vat'] );
		}
		if ( ! empty( $args['job'] ) ) {
			$address['{job}'] = __( 'Job Description Field', 'oxygen' ) . ' ' . strtoupper( $args['job'] );
		}
		if ( ! empty( $args['tax_office'] ) ) {
			$address['{tax_office}'] = __( 'Tax office', 'oxygen' ) . ' ' . strtoupper( $args['tax_office'] );
		}
		if ( ! empty( $args['invoice'] ) ) {
			$address['{invoice}'] = __( 'Issue invoice', 'oxygen' ) . ' ' . strtoupper( $args['invoice'] );
		}

		return $address;
	}

	/**
	 *  Adding new customer billing fields to the order.
	 *
	 *  @param array $fields customer meta data array.
	 *  @return array
	 */
	public function oxygen_admin_billing_fields( $fields ) {

		$fields['vat']        = array(
			'label' => __( 'VAT #', 'oxygen' ),
			'show'  => true,
		);
		$fields['job']        = array(
			'label' => __( 'Job Description Field', 'oxygen' ),
			'show'  => true,
		);
		$fields['tax_office'] = array(
			'label' => __( 'Tax office', 'oxygen' ),
			'show'  => true,
		);
		$fields['invoice']    = array(
			'label'             => __( 'Issue invoice', 'oxygen' ),
			'show'              => true,
			'type'              => 'number',
			'description'       => __( '1 is on, 0 is off', 'oxygen' ),
			'custom_attributes' => array(
				'min' => 0,
				'max' => 1,
			),
		);

		return $fields;
	}

	/**
	 *  Fetching customer meta data fields from the order.
	 *
	 *  @param array  $customer_data customer meta data array.
	 *  @param object $customer WC_Customer.
	 *  @param int    $user_id the user ID.
	 *  @return array
	 */
	public function oxygen_found_customer_details( $customer_data, $customer, $user_id ) {

		$customer_data['billing_vat']        = sanitize_text_field( get_user_meta( $user_id, 'billing_vat', true ) );
		$customer_data['billing_job']        = sanitize_text_field( get_user_meta( $user_id, 'billing_job', true ) );
		$customer_data['billing_tax_office'] = sanitize_text_field( get_user_meta( $user_id, 'billing_tax_office', true ) );
		$customer_data['billing_invoice']    = sanitize_text_field( get_user_meta( $user_id, 'billing_invoice', true ) );

		return $customer_data;
	}

	/**
	 *  Adding new customer meta data fields to the order.
	 *
	 *  @param array $fields customer meta data array.
	 *  @return array
	 */
	public function oxygen_customer_meta_fields( $fields ) {
		$fields['billing']['fields']['billing_vat'] = array(
			'label'       => __( 'VAT #', 'oxygen' ),
			'description' => '',
		);

		$fields['billing']['fields']['billing_job'] = array(
			'label'       => __( 'Job Description Field', 'oxygen' ),
			'description' => '',
		);

		$fields['billing']['fields']['billing_tax_office'] = array(
			'label'       => __( 'Tax Office', 'oxygen' ),
			'description' => '',
		);

		$fields['billing']['fields']['billing_invoice'] = array(
			'label'       => __( 'Issue invoice', 'oxygen' ),
			'description' => '',
			'type'        => 'checkbox',
		);

		return $fields;
	}

	/**
	 *  Adding 1 new column with their titles (keeping "Total" and "Actions" columns at the end).
	 *
	 *  @param array $columns the order list admin columns array.
	 *  @return array
	 */
	public function shop_order_column( $columns ) {

		$reordered_columns = array();

		// Inserting columns to a specific location.
		foreach ( $columns as $key => $column ) {
			$reordered_columns[ $key ] = $column;
			if ( 'order_status' === $key ) {
				// Inserting after "Status" column.
				$reordered_columns['oxygen'] = __( 'Oxygen', 'oxygen' );
			}
		}
		return $reordered_columns;
	}

	/**
	 *  Adding custom fields meta data on new column(s)
	 *
	 *  @param string $column name of the column.
	 *  @param int    $post_id post ID.
	 *  @return void
	 */
	public function orders_list_column_content( $column, $post_id ) {
		switch ( $column ) {
			case 'oxygen':
				// Get custom post meta data.
				$invoice_data = get_post_meta( $post_id, '_oxygen_invoice', true );
				$notice_data  = get_post_meta( $post_id, '_oxygen_notice', true );
				$pdf          = get_post_meta( $post_id, '_oxygen_invoice_pdf', true );

				if ( isset( $invoice_data['iview_url'] ) && ! empty( $invoice_data['iview_url'] ) ) {
					?>
					<div>
						<p>
						<a href="<?php echo esc_url( $invoice_data['iview_url'] ); ?>" target="_blank"><span class="dashicons dashicons-search"></span> <?php esc_html_e( 'View Invoice', 'oxygen' ); ?></a> / 
						<a href="<?php echo esc_url( $pdf ); ?>" target="_blank"><span class="dashicons dashicons-pdf"></span> <?php esc_html_e( 'PDF Download', 'oxygen' ); ?></a> / 
						<?php echo '#<a href="' . esc_url( $invoice_data['iview_url'] ) . '" target="_blank">' . esc_html( $invoice_data['sequence'] . $invoice_data['number'] ) . '</a></strong>'; ?>
						</p>
					</div>
					<?php
				}
				if ( isset( $notice_data['iview_url'] ) && ! empty( $notice_data['iview_url'] ) ) {
					?>
					<div>
						<p>
						<a href="<?php echo esc_url( $notice_data['iview_url'] ); ?>" target="_blank"><span class="dashicons dashicons-media-document"></span> <?php esc_html_e( 'View Notice', 'oxygen' ); ?></a>
						</p>
					</div>
					<?php
				}

				break;
		}
	}

	/**
	 *  On order create actions
	 *
	 *  @param int $order_id the ID of the order.
	 *  @return void
	 */
	public function on_order_create( $order_id ) {

		$order = wc_get_order( $order_id );

		$oxygen_default_receipt_doctype = get_option( 'oxygen_default_receipt_doctype' );
		$oxygen_default_invoice_doctype = get_option( 'oxygen_default_invoice_doctype' );

		$get_billing_vat_info = self::get_billing_vat_info( $order_id );

		if ( false !== $get_billing_vat_info && ! empty( $order->get_billing_company() ) && ! empty( $oxygen_default_invoice_doctype ) ) {

			update_post_meta( $order_id, '_oxygen_payment_note_type', $oxygen_default_receipt_doctype );
		}
		if ( ! empty( $oxygen_default_invoice_doctype ) ) {

			update_post_meta( $order_id, '_oxygen_payment_note_type', $oxygen_default_invoice_doctype );
		}
	}

	/**
	 *  On order save actions
	 *
	 *  @param int    $post_id the ID of the order.
	 *  @param object $post WP_Post.
	 *  @param bool   $update update or new.
	 *  @return void
	 */
	public function save_order( $post_id, $post, $update ) {

		if ( ! is_admin() ) {
			return;
		}

		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
			return;
		}

		if ( ! isset( $_POST['oxygen_nonce'] ) ) {
			return;
		}
		if ( ! wp_verify_nonce( sanitize_key( $_POST['oxygen_nonce'] ), 'oxygen-' . $post_id . '-nonce', 'oxygen_nonce' ) ) {
			return;
		}

		if ( isset( $_POST['_oxygen_payment_note_type'] ) ) {

			update_post_meta( $post_id, '_oxygen_payment_note_type', sanitize_text_field( wp_unslash( $_POST['_oxygen_payment_note_type'] ) ) );
		}

	}

	/**
	 *  Fetches product myData settings
	 *
	 *  @param int $product_id the ID of the product.
	 *  @return array
	 */
	private static function get_product_mydata_info( $product_id ) {

		$meta = get_post_meta( $product_id );

		if ( ! empty( $meta['mydata_category'] ) && ! empty( $meta['mydata_classification_type'] ) ) {

			return array(
				'mydata_category'                    => $meta['mydata_category'],
				'mydata_classification_type'         => $meta['mydata_classification_type'],
				'mydata_category_receipt'            => $meta['mydata_category_receipt'],
				'mydata_classification_type_receipt' => $meta['mydata_classification_type_receipt'],
			);

		}

		$categories = get_the_terms( $product_id, 'product_cat' );

		if ( ! empty( $categories ) && is_array( $categories ) ) {

			foreach ( $categories as $cat ) {

				$mydata_category                    = get_term_meta( $cat->term_id, 'mydata_category', true );
				$mydata_classification_type         = get_term_meta( $cat->term_id, 'mydata_classification_type', true );
				$mydata_category_receipt            = get_term_meta( $cat->term_id, 'mydata_category_receipt', true );
				$mydata_classification_type_receipt = get_term_meta( $cat->term_id, 'mydata_classification_type_receipt', true );

				if ( ! empty( $mydata_category ) && ! empty( $mydata_classification_type ) ) {

					return array(
						'mydata_category'            => $mydata_category,
						'mydata_classification_type' => $mydata_classification_type,
						'mydata_category_receipt'    => $mydata_category_receipt,
						'mydata_classification_type_receipt' => $mydata_classification_type_receipt,
					);

				}
			}
		}

		return array(
			'mydata_category'                    => get_option( 'mydata_category' ),
			'mydata_classification_type'         => get_option( 'mydata_classification_type' ),
			'mydata_category_receipt'            => get_option( 'mydata_category_receipt' ),
			'mydata_classification_type_receipt' => get_option( 'mydata_classification_type_receipt' ),
		);

	}

	/**
	 *  Fetches product myData receipt settings
	 *
	 *  @param int $product_id the ID of the product.
	 *  @return array
	 */
	private static function get_product_mydata_receipt_info( $product_id ) {

		$meta = get_post_meta( $product_id );

		if ( ! empty( $meta['mydata_category'] ) && ! empty( $meta['mydata_classification_type'] ) ) {

			return array(
				'mydata_category'            => $meta['mydata_category_receipt'],
				'mydata_classification_type' => $meta['mydata_classification_type_receipt'],
			);

		}

		$categories = get_the_terms( $product_id, 'product_cat' );

		if ( ! empty( $categories ) && is_array( $categories ) ) {

			foreach ( $categories as $cat ) {

				$mydata_category            = get_term_meta( $cat->term_id, 'mydata_category_receipt', true );
				$mydata_classification_type = get_term_meta( $cat->term_id, 'mydata_classification_type_receipt', true );

				if ( ! empty( $mydata_category ) && ! empty( $mydata_classification_type ) ) {

					return array(
						'mydata_category'            => $mydata_category,
						'mydata_classification_type' => $mydata_classification_type,
					);

				}
			}
		}

		return array(
			'mydata_category'            => get_option( 'mydata_category_receipt' ),
			'mydata_classification_type' => get_option( 'mydata_classification_type_receipt' ),
		);

	}

	/**
	 *  New user actions on orders list table
	 *
	 *  @param array  $actions Array of user actions.
	 *  @param object $order WC_Order.
	 *  @return array
	 */
	public function my_account_my_orders_actions( $actions, $order ) {

		$invoice_data = get_post_meta( $order->get_id(), '_oxygen_invoice', true );
		$notice_data  = get_post_meta( $order->get_id(), '_oxygen_notice', true );
		$pdf          = get_post_meta( $order->get_id(), '_oxygen_invoice_pdf', true );

		if ( isset( $invoice_data['iview_url'] ) && ! empty( esc_url( $invoice_data['iview_url'] ) ) ) {
			?>
			<div>
				<p>
				<a href="<?php echo esc_url( $invoice_data['iview_url'] ); ?>" target="_blank" title="<?php esc_attr_e( 'View Invoice', 'oxygen' ); ?>" class="woocommerce-button button" style="margin-bottom: 2px;"><?php esc_html_e( 'View Invoice', 'oxygen' ); ?> <span class="dashicons dashicons-search"></span></a><br />
				<a href="<?php echo esc_url( $pdf ); ?>" target="_blank" title="<?php esc_html_e( 'PDF Download', 'oxygen' ); ?>" class="woocommerce-button button"  style="margin-bottom: 2px;"><?php esc_html_e( 'PDF Download', 'oxygen' ); ?> <span class="dashicons dashicons-pdf"></span></a><br />
				</p>
			</div>
			<?php
		}
		if ( isset( $notice_data['iview_url'] ) && ! empty( $notice_data['iview_url'] ) ) {
			?>
			<div>
				<p>
				<a href="<?php echo esc_url( $notice_data['iview_url'] ); ?>" target="_blank"><span class="dashicons dashicons-media-document"></span> <?php esc_html_e( 'View Notice', 'oxygen' ); ?></a>
				</p>
			</div>
			<?php
		}

		return $actions;
	}

}
